@@ -91,9 +91,9 @@ def fis_tools_quitar_tildes(palabra):
     #Aplicamos el traductor y devolvemos la palabra limpia
     return(palabra.translate(traductor))
     
-def fis_tools_pre_strong_corr(df, lim_inf = 0.3, lim_sup = 1,drop_dupli=True):
+def fis_tools_pre_strong_corr(df,lim_inf = 0.3, lim_sup = 1,drop_dupli=True):
     #Calcula la matriz de correlación
-    c = x.corr().abs()
+    c = df.corr().abs()
     #Lo pasa todo a filas
     c= c.unstack()
     #Pasa el índice a columnas y le pone nombres
